import 'package:cached_network_image/cached_network_image.dart';
import 'package:flutter/material.dart';

class CircularUserAvatar extends StatefulWidget {
  final double radius;
  final double elevation;
  final Color borderColor;
  final Color backgroundColor;
  final String imageUrl;
  final Text userNameInitialsText;
  final bool cacheImage;
  final LoadingErrorWidgetBuilder errorWidget;  

  CircularUserAvatar(this.imageUrl,
      {Key key,
      this.userNameInitialsText = const Text(''),
      this.cacheImage = true,
      this.radius = 50.0,
      this.borderColor = Colors.black,
      this.backgroundColor = Colors.white,
      this.elevation = 0.0,
      this.errorWidget})
      : super(key: key);

  @override
  _CircularUserAvatarState createState() => _CircularUserAvatarState();
}

class _CircularUserAvatarState extends State<CircularUserAvatar> {
  Widget _initialsText;
  @override
  Widget build(BuildContext context) {
    _initialsText = Center(child: widget.userNameInitialsText);
    return Container(
      child: Material(
        type: MaterialType.circle,
        elevation: widget.elevation,
        color: widget.borderColor,
        child: Container(
            height: widget.radius * 2,
            width: widget.radius * 2,
            decoration: BoxDecoration(
                borderRadius: BorderRadius.circular(widget.radius),
                color: widget.borderColor),
            child: Center(
              child: Container(
                decoration: BoxDecoration(
                    color: widget.backgroundColor,
                    borderRadius: BorderRadius.circular(widget.radius)),
                child: Stack(
                  fit: StackFit.expand,
                  children: widget.imageUrl.isEmpty
                      ? <Widget>[_initialsText]
                      : <Widget>[profileImage()],
                ),
              ),
            )),
      ),
    );
  }

  Widget profileImage() {
    return widget.cacheImage
        ? ClipRRect(
            borderRadius: BorderRadius.circular(widget.radius),
            child: CachedNetworkImage(
              fit: BoxFit.cover,
              imageUrl: widget.imageUrl,
              errorWidget: widget.errorWidget,              
            ),
          )
        : CircleAvatar(
            backgroundImage: NetworkImage(widget.imageUrl),
          );
  }
}
